==> htmlunit-cssparser-3.3.0-sources.jar: org/htmlunit/cssparser/parser/selector/PseudoElementSelector.java <==
/*
 * Copyright (c) 2019-2023 Ronald Brill.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.htmlunit.cssparser.parser.selector;

import org.htmlunit.cssparser.parser.Locator;

/**
 *
 * @author Ronald Brill
 */
public class PseudoElementSelector extends AbstractSelector implements SimpleSelector {

    private final String localName_;
    private final boolean doubleColon_;

    /**
     * Ctor.
     * @param localName the local name
     * @param locator the locator
     * @param doubleColon double column flag
     */
    public PseudoElementSelector(final String localName, final Locator locator, final boolean doubleColon) {
        localName_ = localName;
        setLocator(locator);
        doubleColon_ = doubleColon;
    }

    @Override
    public SelectorType getSelectorType() {
        return SelectorType.PSEUDO_ELEMENT_SELECTOR;
    }

    @Override
    public SimpleSelector getSimpleSelector() {
        return this;
    }

    /**
     * @return the local name
     */
    public String getLocalName() {
        return localName_;
    }

    @Override
    public String toString() {
        if (localName_ == null) {
            return localName_;
        }
        return (doubleColon_ ? "::" : ":") + localName_;
    }
}

==> htmlunit-cssparser-3.9.0-sources.jar: org/htmlunit/cssparser/parser/selector/PseudoElementSelector.java <==
/*
 * Copyright (c) 2019-2023 Ronald Brill.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.htmlunit.cssparser.parser.selector;

import org.htmlunit.cssparser.parser.Locator;

/**
 * <p>PseudoElementSelector class.</p>
 *
 * @author Ronald Brill
 */
public class PseudoElementSelector extends AbstractSelector implements SimpleSelector {

    private final String localName_;
    private final boolean doubleColon_;

    /**
     * Ctor.
     * @param localName the local name
     * @param locator the locator
     * @param doubleColon double column flag
     */
    public PseudoElementSelector(final String localName, final Locator locator, final boolean doubleColon) {
        localName_ = localName;
        setLocator(locator);
        doubleColon_ = doubleColon;
    }

    /** {@inheritDoc} */
    @Override
    public SelectorType getSelectorType() {
        return SelectorType.PSEUDO_ELEMENT_SELECTOR;
    }

    /** {@inheritDoc} */
    @Override
    public SimpleSelector getSimpleSelector() {
        return this;
    }

    /**
     * <p>getLocalName.</p>
     *
     * @return the local name
     */
    public String getLocalName() {
        return localName_;
    }

    /** {@inheritDoc} */
    @Override
    public String toString() {
        if (localName_ == null) {
            return localName_;
        }
        return (doubleColon_ ? "::" : ":") + localName_;
    }
}
